Learn R Programming

ZetaSuite (version 1.0.2)

posGene: Input positive file.

Description

A data frame with 299 different well IDs in which the cells treated with siRNAs targeting to PTB.If users didn't have the build-in positive controls, choose the parameters -withoutsvm and the filename can use any name such as 'NA'.

Usage

data("negGene")

Arguments

Format

A data frame with 299 different well IDs in which the cells treated with siRNAs targeting to PTB.

A data frame with 299 different well IDs in which the cells treated with siRNAs targeting to PTB. These wells were served as positive control.

Details

These wells were designed by the authors in the large-scale screen.

Examples

Run this code
  data(posGene)

Run the code above in your browser using DataLab